@@ -1,24 +1,25 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
-
+from velbus.message import Message
+from velbus.command_registry import register_command
 COMMAND_CODE = 0xf5
 
 
-class ClearLedMessage(velbus.Message):
+class ClearLedMessage(Message):
     """
     send by: VMB4RYLD
     received by: VMB6IN, VMB4RYLD
     """
 
-    def __init__(self):
-        velbus.Message.__init__(self)
+    def __init__(self, address=None):
+        Message.__init__(self)
         self.clear_leds = []
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -29,9 +30,9 @@ class ClearLedMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([COMMAND_CODE, self.channels_to_byte(self.clear_leds)])
 
 
-velbus.register_command(COMMAND_CODE, ClearLedMessage)
+register_command(COMMAND_CODE, ClearLedMessage)
