@@ -1,26 +1,28 @@
 """
-@author: Thomas Delaet <thomas@delaet.org>
+:author: Thomas Delaet <thomas@delaet.org>
 """
-import velbus
+from velbus.message import Message
+from velbus.command_registry import register_command
 
 COMMAND_CODE = 0xf4
 
 
-class UpdateLedStatusMessage(velbus.Message):
+class UpdateLedStatusMessage(Message):
     """
     send by:
     received by: VMB6IN
     """
 
-    def __init__(self):
-        velbus.Message.__init__(self)
+    def __init__(self, address=None):
+        Message.__init__(self)
         self.led_on = []
         self.led_slow_blinking = []
         self.led_fast_blinking = []
+        self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
         """
-        @return None
+        :return: None
         """
         assert isinstance(data, bytes)
         self.needs_low_priority(priority)
@@ -33,7 +35,7 @@ class UpdateLedStatusMessage(velbus.Message):
 
     def data_to_binary(self):
         """
-        @return: bytes
+        :return: bytes
         """
         return bytes([
             COMMAND_CODE,
@@ -43,4 +45,4 @@ class UpdateLedStatusMessage(velbus.Message):
         ])
 
 
-velbus.register_command(COMMAND_CODE, UpdateLedStatusMessage)
+register_command(COMMAND_CODE, UpdateLedStatusMessage)
